@@ -417,32 +417,33 @@ setMethod("sim_fitted", "ubmsFitDistsamp", function(object, submodel, samples, .
 #Histogram---------------------------------------------------------------------
 
 #' @importFrom graphics hist
-#' @importFrom ggplot2 geom_histogram
+#' @importFrom ggplot2 geom_histogram after_stat
 setMethod("hist", "ubmsFitDistsamp", function(x, draws=30, ...){
   samples <- get_samples(x, draws)
   hist_data <- get_hist_data(x)
   mean_line <- get_mean_line(x)
-
-  out <- ggplot(hist_data, aes_string(x="x")) +
-    geom_histogram(aes_string(y="..density.."),fill='transparent',
+  
+  xval <- sym("x"); val <- sym("val"); ind <- sym("ind"); dens <- sym("density")
+  out <- ggplot(hist_data, aes(x={{xval}})) +
+    geom_histogram(aes(y=after_stat({{dens}})),fill='transparent',
                    col='black',breaks=x@response@dist_breaks)
 
   #Adjust the histogram height to match the density line
   bar_height <- ggplot2::ggplot_build(out)$data[[1]]$y[1]
   adj_factor <- max(mean_line$val, na.rm=TRUE) / bar_height
 
-  out <- ggplot(hist_data, aes_string(x="x")) +
-    geom_histogram(aes_string(y=paste0("..density..*",adj_factor)),fill='transparent',
+  out <- ggplot(hist_data, aes(x={{xval}})) +
+    geom_histogram(aes(y=after_stat({{dens}})*adj_factor),fill='transparent',
                    col='black',breaks=x@response@dist_breaks)
 
   if(draws > 0){
     sample_lines <- get_sample_lines(x, samples)
     out <- out +
-      geom_line(data=sample_lines, aes_string(x="x", y="val", group="ind"),
+      geom_line(data=sample_lines, aes(x={{xval}}, y={{val}}, group={{ind}}),
               alpha=0.3)
   }
   out +
-    geom_line(data=mean_line, aes_string(x="x", y="val"), col='red') +
+    geom_line(data=mean_line, aes(x={{xval}}, y={{val}}), col='red') +
     labs(x=paste0("Distance (", x@response@units_in,")"), y="Density") +
     theme_bw() +
     theme(panel.grid.major=element_blank(), panel.grid.minor=element_blank(),
