@@ -94,7 +94,7 @@ setMethod("model.matrix", "ubmsSubmodel",
   formula <- lme4::nobars(object@formula)
   out <- model.matrix(formula, mf)
   if(na.rm) out <- out[!object@missing,,drop=FALSE]
-  if(warn){
+  if(warn & !all(is.na(out))){
     max_cov <- max(out, na.rm=TRUE)
     if(max_cov > 4){
       warning(paste0("Covariates possibly not standardized (max value = ", max_cov,
@@ -139,7 +139,7 @@ get_xlev <- function(data, model_frame){
 get_reTrms <- function(formula, data, newdata=NULL){
   fb <- lme4::findbars(formula)
   mf <- model.frame(lme4::subbars(formula), data, na.action=stats::na.pass)
-  if(is.null(newdata)) return(lme4::mkReTrms(fb, mf))
+  if(is.null(newdata)) return(lme4::mkReTrms(fb, mf, drop.unused.levels=FALSE))
   new_mf <- model.frame(stats::terms(mf), newdata, na.action=stats::na.pass,
                         xlev=get_xlev(data, mf))
   lme4::mkReTrms(fb, new_mf, drop.unused.levels=FALSE)
@@ -164,14 +164,17 @@ check_formula <- function(formula, data){
   rand <- lme4::findbars(formula)
   if(is.null(rand)) return(invisible())
 
-  char <- paste(deparse(formula))
+  char <- paste(lme4::findbars(formula)[[1]], collapse=" ")
   if(grepl(":|/", char)){
     stop("Nested random effects (using / and :) are not supported",
          call.=FALSE)
   }
   theta <- get_reTrms(formula, data)$theta
   if(0 %in% theta){
-    stop("Correlated slopes and intercepts are not supported. Use || instead of |.",
+    stop("Failed to create random effects model matrix.\n
+Possible reasons:\n
+(1) Correlated slopes and intercepts are not supported. Replace | with || in your formula(s).\n
+(2) You have specified random slopes for an R factor variable. Try converting the variable to a series of indicator variables instead.",
          call.=FALSE)
   }
 }
